==> gmic_2.3.0.tar.gz: gmic-2.3.0/gmic-qt/src/FilterSelector/FiltersView/FilterTreeItem.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file FilterTreeItem.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef _GMIC_QT_FILTERTREEITEM_H_
#define _GMIC_QT_FILTERTREEITEM_H_
#include <QStandardItem>
#include <QString>
#include "FilterSelector/FiltersView/FilterTreeAbstractItem.h"

class FilterTreeItem : public FilterTreeAbstractItem {
public:
  FilterTreeItem(QString text);
  void setHash(const QString & hash);
  void setWarningFlag(bool flag);
  void setFaveFlag(bool flag);
  bool isWarning() const;
  bool isFave() const;
  QString hash() const;
  bool operator<(const QStandardItem & other) const override;

private:
  QString _hash;
  bool _isFave;
  bool _isWarning;
};

#endif // _GMIC_QT_FILTERTREEITEM_H_

==> gmic_2.9.8.tar.gz: gmic-2.9.8/gmic-qt/src/FilterSelector/FiltersView/FilterTreeItem.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file FilterTreeItem.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_FILTERTREEITEM_H
#define GMIC_QT_FILTERTREEITEM_H
#include <QStandardItem>
#include <QString>
#include "FilterSelector/FiltersView/FilterTreeAbstractItem.h"

namespace GmicQt
{
class FilterTreeItem : public FilterTreeAbstractItem {
public:
  FilterTreeItem(const QString & text);
  void setHash(const QString & hash);
  void setWarningFlag(bool flag);
  void setFaveFlag(bool flag);
  bool isWarning() const;
  bool isFave() const;
  QString hash() const;
  bool operator<(const QStandardItem & other) const override;

private:
  QString _hash;
  bool _isFave;
  bool _isWarning;
};

} // namespace GmicQt

#endif // GMIC_QT_FILTERTREEITEM_H
